@@ -7,41 +7,28 @@
 # Version: 0.08
 #
 # Copyright 1999-2001 Fabien Tassin <fta@sofaraway.org>
-# Copyright 2007      Markus Baertschi <markus@markus.org>
+# Copyright 2007  Markus Baertschi
 #
-# 03.09.2007  0.08  Markus Baertschi <markus@markus.org>
-#                   - Fixed error checking on file open
-#    04.2008  0.09  Markus Baertschi <markus@markus.org>
-#                   - Clarified documentation
-# 28.05.2008  0.10  Markus Baertschi <markus@markus.org>
-#                   - Additional error checking in encode
-#                   - Made DEBUG accessible from outside
-#                   - Add more debug statements
-#                   - Fixed 'Rotate'
-#                   - Added 'number' to encode (required for 'Rotate')
-#                   - More Comments and POD Cleanup
+# 03.09.2007  0.08  Markus Baertschi
+#                   - Fixed error cheking on file open
 
 package PDF::Create;
 
-our $VERSION = "0.10";
-our $DEBUG   = 0;
-
 use strict;
-use Carp qw(confess croak cluck carp);
+use vars qw(@ISA @EXPORT $VERSION $DEBUG);
+use Exporter;
+use Carp;
 use FileHandle;
 use PDF::Create::Page;
 use PDF::Create::Outline;
 use PDF::Image::GIFImage;
 use PDF::Image::JPEGImage;
-use vars qw($DEBUG);
 
-our (@ISA, @EXPORT, @EXPORT_OK, @EXPORT_FAIL);
-require Exporter;
 @ISA     = qw(Exporter);
 @EXPORT  = qw();
-@EXPORT_OK = qw($DEBUG $VERSION);
+$VERSION = 0.9;
+$DEBUG   = 0;
 
-# Create a new object
 sub new {
   my $this = shift;
   my %params = @_;
@@ -96,15 +83,10 @@ sub new {
   return $self;
 }
 
-#
-# Close does the work of creating the PDF data from the
-# objects collected before.
-#
 sub close {
   my $self = shift;
   my %params = @_;
 
-  $self->debug("Closing PDF");
   $self->page_stream;
   $self->add_outlines if defined $self->{'outlines'};
   $self->add_catalog;
@@ -117,10 +99,6 @@ sub close {
   $self->{'data'};
 }
 
-#
-# Helper fonction for debugging
-# Prints the passed message if debugging is on
-#
 sub debug {
   return unless $DEBUG;
   my $self = shift;
@@ -130,9 +108,6 @@ sub debug {
   warn "PDF DEBUG: $s\n";
 }
 
-#
-# Set/Return the PDF version
-#
 sub version {
   my $self = shift;
   my $v = shift;
@@ -199,10 +174,6 @@ sub add_comment {
 sub encode {
   my $type = shift;
   my $val = shift;
-
-  if ($DEBUG) {if ($val) {warn("encode: $type $val");}
-                    else {warn("encode: $type (no val)");}}
-  if (! $type) {cluck "PDF::Create::encode: empty argument, called by "; return 1}
   ($type eq 'null' || $type eq 'number') && do {
     1; # do nothing
   } || $type eq 'cr' && do {
@@ -212,12 +183,9 @@ sub encode {
     $val eq '0' ? 'false' : 'true';
   } || $type eq 'string' && do {
     $val = "($val)"; # TODO: split it. Quote parentheses.
-  } || $type eq 'number' && do {
-    $val = "$val";
   } || $type eq 'name' && do {
     $val = "/$val";
   } || $type eq 'array' && do {
-    # array, encode contents individually
     my $s = '[';
     for my $v (@$val) {
       $s .= &encode($$v[0], $$v[1]) . " ";
@@ -254,7 +222,7 @@ sub encode {
     $s .= ">>" . &encode('cr') . "stream" . &encode('cr');
     $s .= $data . &encode('cr');
     $val = $s . "endstream" . &encode('cr');
-  } || confess "Error: unknown type '$type'";
+  } || die "Error: unknown type '$type'";
   # TODO: add type 'text';
   $val;
 }
@@ -343,7 +311,6 @@ sub stream {
 sub add_info {
   my $self = shift;
 
-  $self->debug("add_info");
   my %params = @_;
   $params{'Author'}       = $self->{'Author'}   if defined $self->{'Author'};
   $params{'Creator'}      = $self->{'Creator'}  if defined $self->{'Creator'};
@@ -378,7 +345,6 @@ sub add_info {
 sub add_catalog {
   my $self = shift;
 
-  $self->debug("add_catalog");
   my %params = %{$self->{'catalog'}};
   # Type (mandatory)
   $self->{'catalog'} = $self->reserve('Catalog');
@@ -403,7 +369,6 @@ sub add_catalog {
 sub add_outlines {
   my $self = shift;
 
-  $self->debug("add_outlines");
   my %params = @_;
   my $outlines = $self->reserve("Outlines");
 
@@ -527,7 +492,6 @@ sub new_page {
 sub add_pages {
   my $self = shift;
 
-  $self->debug("add_pages");
   # $self->page_stream;
   my %params = @_;
   # Type (required)
@@ -546,7 +510,6 @@ sub add_pages {
   $self->cr;
 
   for my $font (sort keys %{$self->{'fonts'}}) {
-    $self->debug("add_pages: font: $font");
     $self->{'fontobj'}{$font} = $self->reserve('Font');
     $self->add_object(
       $self->indirect_obj(
@@ -555,7 +518,6 @@ sub add_pages {
   }
 
   for my $xobject (sort keys %{$self->{'xobjects'}}) {
-    $self->debug("add_pages: object: $xobject");
     $self->{'xobj'}{$xobject} = $self->reserve('XObject');
     $self->add_object(
       $self->indirect_obj(
@@ -572,7 +534,6 @@ sub add_pages {
 
   for my $page ($self->{'pages'}->list) {
     my $name = $page->{'name'};
-    $self->debug("add_pages: page: $name");
     my $type = 'Page' .
       (defined $page->{'Kids'} && scalar @{$page->{'Kids'}} ? 's' : '');
     # Type (required)
@@ -624,7 +585,7 @@ sub add_pages {
 	$$content{$K} = $self->array(@$l);
       }
     }
-    $$content{'Rotate'} = $self->number($page->{'rotate'}) if defined $page->{'rotate'};
+    $$content{'Rotate'} = $page->{'rotate'} if defined $page->{'rotate'};
     if ($type eq 'Page') {
       $$content{'Parent'} = $self->indirect_ref(@{$page->{'Parent'}{'id'}});
       # Content
@@ -765,8 +726,6 @@ sub cr {
 sub page_stream {
   my $self = shift;
   my $page = shift;
-#  $self->debug("page_stream: page=$page");
-
   if (defined $self->{'reservations'}{'stream_length'}) {
     ## If it is the same page, use the same stream.
     $self->cr, return if defined $page && defined $self->{'stream_page'} &&
@@ -937,72 +896,72 @@ PDF::Create - create PDF files
 
 =head1 SYNOPSIS
 
-  use PDF::Create;
+use PDF::Create;
 
-  my $pdf = new PDF::Create('filename'     => 'mypdf.pdf',
-			    'Version'      => 1.2,
-			    'PageMode'     => 'UseOutlines',
-			    'Author'       => 'John Doe',
-			    'Title'        => 'My Title',
-			    'CreationDate' => [ localtime ],
-			   );
-  # add a A4 sized page
-  my $root = $pdf->new_page('MediaBox' => $pdf->get_page_size('A4'));
+my $pdf = new PDF::Create('filename'     => 'mypdf.pdf',
+			  'Version'      => 1.2,
+			  'PageMode'     => 'UseOutlines',
+			  'Author'       => 'John Doe',
+			  'Title'        => 'My Title',
+			  'CreationDate' => [ localtime ],
+			 );
+# add a A4 sized page
+my $root = $pdf->new_page('MediaBox' => $pdf->get_page_size('A4'));
 
-  # Add a page which inherits its attributes from $root
-  my $page = $root->new_page;
+# Add a page which inherits its attributes from $root
+my $page = $root->new_page;
 
-  # Prepare 2 fonts
-  my $f1 = $pdf->font('Subtype'  => 'Type1',
-   		      'Encoding' => 'WinAnsiEncoding',
- 		      'BaseFont' => 'Helvetica');
-  my $f2 = $pdf->font('Subtype'  => 'Type1',
- 		      'Encoding' => 'WinAnsiEncoding',
- 		      'BaseFont' => 'Helvetica-Bold');
+# Prepare 2 fonts
+my $f1 = $pdf->font('Subtype'  => 'Type1',
+   		    'Encoding' => 'WinAnsiEncoding',
+ 		    'BaseFont' => 'Helvetica');
+my $f2 = $pdf->font('Subtype'  => 'Type1',
+ 		    'Encoding' => 'WinAnsiEncoding',
+ 		    'BaseFont' => 'Helvetica-Bold');
 
-  # Prepare a Table of Content
-  my $toc = $pdf->new_outline('Title' => 'Document',
-                              'Destination' => $page);
-  $toc->new_outline('Title' => 'Section 1');
-  my $s2 = $toc->new_outline('Title' => 'Section 2',
-                             'Status' => 'closed');
-  $s2->new_outline('Title' => 'Subsection 1');
+# Prepare a Table of Content
+my $toc = $pdf->new_outline('Title' => 'Document',
+                            'Destination' => $page);
+$toc->new_outline('Title' => 'Section 1');
+my $s2 = $toc->new_outline('Title' => 'Section 2',
+                           'Status' => 'closed');
+$s2->new_outline('Title' => 'Subsection 1');
 
-  $page->stringc($f2, 40, 306, 426, "PDF::Create");
-  $page->stringc($f1, 20, 306, 396, "version $PDF::Create::VERSION");
+$page->stringc($f2, 40, 306, 426, "PDF::Create");
+$page->stringc($f1, 20, 306, 396, "version $PDF::Create::VERSION");
 
-  # Add another page
-  my $page2 = $root->new_page;
-  $page2->line(0, 0, 612, 792);
-  $page2->line(0, 792, 612, 0);
+# Add another page
+my $page2 = $root->new_page;
+$page2->line(0, 0, 612, 792);
+$page2->line(0, 792, 612, 0);
 
-  $toc->new_outline('Title' => 'Section 3');
-  $pdf->new_outline('Title' => 'Summary');
+$toc->new_outline('Title' => 'Section 3');
+$pdf->new_outline('Title' => 'Summary');
 
-  # Add something to the first page
-  $page->stringc($f1, 20, 306, 300, 'by John Doe <john.doe@example.com>');
+# Add something to the first page
+$page->stringc($f1, 20, 306, 300, 'by John Doe <john.doe@example.com>');
 
-  # Add the missing PDF objects and a the footer then close the file
-  $pdf->close;
+# Add the missing PDF objects and a the footer then close the file
+$pdf->close;
 
 =head1 DESCRIPTION
 
-PDF::Create allows you to create PDF documents using a number of
-primitives. The result is as a PDF file or stream.
-
+PDF::Create allows you to create PDF documents using a large number
+of primitives, and emit the result as a PDF file or stream.
 PDF stands for Portable Document Format.
 
 Documents can have several pages, a table of content, an information
-section and many other PDF elements.
+section and many other PDF elements. More functionnalities will be
+added as needs arise.
 
-Documents are built on the fly so the memory footprint is not
+Documents are constructed on the fly so the memory footprint is not
 tied to the size of the pages but only to their number.
 
 =head1 Methods
 
 =over 5
 
-=item new
+=item C<new>
 
 To create a new PDF, send a new() message to the PDF::Create class.
 For example:
@@ -1059,22 +1018,22 @@ Example:
 
 The created object is returned.
 
-=item close
+=item C<close>
 
-Most of the real work building the PDF is performed in the close method.
-It can there fore not be omitted, like a file close.
+Add the missing sections needed to obtain a complete and valid PDF
+document then close the file if needed.
 
-=item get_data
+=item C<get_data>
 
 If you didn't ask the $pdf object to write its output to a file, you
 can pick up the pdf code by calling this method. It returns a big string.
 You need to call C<close> first, mind.
 
-=item add_comment [string]
+=item C<add_comment [string]>
 
 Add a comment to the document.
 
-=item new_outline [parameters]
+=item C<new_outline [parameters]>
 
 Add an outline to the document using the given parameters.
 Return the newly created outline.
@@ -1092,15 +1051,15 @@ outline object.
 
 Example:
 
-  my $outline = $pdf->new_outline('Title' => 'Item 1',
-                                  'Destination' => $page);
-  $outline->new_outline('Title' => 'Item 1.1');
-  $pdf->new_outline('Title' => 'Item 1.2',
-                    'Parent' => $outline);
-  $pdf->new_outline('Title' => 'Item 2');
+          my $outline = $pdf->new_outline('Title' => 'Item 1',
+                                          'Destination' => $page);
+          $outline->new_outline('Title' => 'Item 1.1');
+          $pdf->new_outline('Title' => 'Item 1.2',
+                            'Parent' => $outline);
+          $pdf->new_outline('Title' => 'Item 2');
 
 
-=item new_page
+=item C<new_page>
 
 Add a page to the document using the given parameters.
 Return the newly created page.
@@ -1144,17 +1103,16 @@ fall outside the bleed box. The default is the value of the CropBox.
 
 - Rotate: Specifies the number of degrees the page should be rotated
 clockwise when it is displayed or printed. This value must be zero
-(the default) or a multiple of 90. The entire page, including contents
-is rotated.
+(the default) or a multiple of 90.
 
-=item get_page_size
+=item C<get_page_size>
 
 Returns the size of standard paper sizes to use for MediaBox-parameter
 of C<new_page>. C<get_page_size> has one required parameter to 
 specify the paper name. Possible values are a0-a6, letter, broadsheet,
 ledger, tabloid, legal, executive and 36x36. Default is a4.
 
-=item font
+=item C<font>
 
 Prepare a font using the given arguments. This font will be added
 to the document only if it is used at least once before the close method
@@ -1175,18 +1133,18 @@ In this version, only WinAnsiEncoding is supported. This is the default
 value.
 
 - BaseFont: The PostScript name of the font. It can be one of the following
-base fonts: Courier, Courier-Bold, Courier-BoldOblique, Courier-Oblique,
+base font: Courier, Courier-Bold, Courier-BoldOblique, Courier-Oblique,
 Helvetica, Helvetica-Bold, Helvetica-BoldOblique, Helvetica-Oblique,
-Times-Roman, Times-Bold, Times-Italic or Times-BoldItalic.
+Times-Roman, Times-Bold, Times-Italic, Times-BoldItalic, Symbol or
+ZapfDingbats. All of them are supported in this version except the last two
+ones.
 
-The Symbol or ZapfDingbats fonts are not supported in this version.
+The default value is Helvetica.
 
-The default font is Helvetica.
-
-=item image filename
+=item C<image filename>
 
 Prepare an XObject (image) using the given arguments. This image will be added
-to the document if it is referenced at least once before the close method
+to the document only if it is used at least once before the close method
 is called. In this version GIF, interlaced GIF and JPEG is supported. 
 Usage of interlaced GIFs are slower because they are decompressed, modified 
 and compressed again.
@@ -1195,8 +1153,6 @@ Parameters:
 
 - filename: file name of image (required).
 
-=back
-
 =head2 Page methods
 
 This section describes the methods that can be used by a PDF::Create::Page
@@ -1208,15 +1164,13 @@ drawing (using PostScript like paths) and one for writing.
 Some methods are not described here because they must not be called
 directly (e.g. C<new> and C<add>).
 
-=over 5
-
-=item new_page params
+=item C<new_page params>
 
 Add a sub-page to the current page.
 
 See C<PDF::Create::new_page>
 
-=item string font size x y text
+=item C<string font size x y text>
 
 Add text to the current page using the font object at the given size and
 position. The point (x, y) is the bottom left corner of the rectangle
@@ -1229,19 +1183,19 @@ Example :
  		        'BaseFont' => 'Helvetica');
     $page->string($f1, 20, 306, 396, "some text");
 
-=item stringl font size x y text
+=item C<stringl font size x y text>
 
 Same as C<string>.
 
-=item stringr font size x y text
+=item C<stringr font size x y text>
 
 Same as C<string> but right aligned.
 
-=item stringc font size x y text
+=item C<stringc font size x y text>
 
 Same as C<string> but centered.
 
-=item printnl text font size x y
+=item C<printnl text font size x y>
 
 Similar to C<string> but parses the string for newline and prints each part
 on a separate line. Lines spacing is the same as the font-size. Returns the
@@ -1252,59 +1206,55 @@ parameters, font is the absolute minimum, a warning will be given for the
 missing y position and 800 will be assumed. All subsequent invocations can
 omit all but the string parameters.
 
-=item string_width font text
+=item C<string_width font text>
 
 Return the size of the text using the given font in default user space units.
 This does not contain the size of the font yet.
 
-=item line x1 y1 x2 y2
+=item C<line x1 y1 x2 y2>
 
 Draw a line between (x1, y1) and (x2, y2).
 
-=item set_width w
+=item C<set_width w>
 
 Set the width of subsequent lines to w points.
 
-=item setrgbcolor r g b
+=item C<setrgbcolor r g b>
 
 Set the color of the subsequent drawing operations. R,G and B is a value
 between 0.0 and 1.0.
 
-=back
-
 =head2 Low level drawing methods
 
-=over 5
-
-=item moveto x y
+=item C<moveto x y>
 
 Moves the current point to (x, y), omitting any connecting line segment.
 
-=item lineto x y
+=item C<lineto x y>
 
 Appends a straight line segment from the current point to (x, y).
 The current point is (x, y).
 
-=item curveto x1 y1 x2 y2 x3 y3
+=item C<curveto x1 y1 x2 y2 x3 y3>
 
 Appends a Bezier curve to the path. The curve extends from the current
 point to (x3 ,y3) using (x1 ,y1) and (x2 ,y2) as the Bezier control
 points. The new current point is (x3 ,y3).
 
-=item rectangle x y w h
+=item C<rectangle x y w h>
 
 Adds a rectangle to the current path.
 
-=item closepath
+=item C<closepath>
 
 Closes the current subpath by appending a straight line segment
 from the current point to the starting point of the subpath.
 
-=item newpath
+=item C<newpath>
 
 Ends the path without filling or stroking it.
 
-=item stroke
+=item C<stroke>
 
 Strokes the path.
 
@@ -1316,19 +1266,19 @@ $page->moveto 100 100;
 $page->lineto 200 100;
 $page->stroke;
 
-=item closestroke
+=item C<closestroke>
 
 Closes and strokes the path.
 
-=item fill
+=item C<fill>
 
 Fills the path using the non-zero winding number rule.
 
-=item fill2
+=item C<fill2>
 
 Fills the path using the even-odd rule
 
-=item image image_id xpos ypos xalign yalign xscale yscale rotate xskew yskew
+=item C<image image_id xpos ypos xalign yalign xscale yscale rotate xskew yskew>
 
 Inserts an image.
 
@@ -1350,7 +1300,7 @@ Parameters can be:
 
 =head1 SEE ALSO
 
-L<PDF::Create::Page>, L<perl>, L<http://www.adobe.com/devnet/pdf/pdf_reference.html>
+L<PDF::Create::Page(3)>, L<perl(1)>
 
 =head1 AUTHORS
 
@@ -1358,7 +1308,7 @@ Fabien Tassin (fta@sofaraway.org)
 
 GIF and JPEG-support: Michael Gross (mdgrosse@sbox.tugraz.at)
 
-Maintenance since 2007: Markus Baertschi (markus@markus.org)
+Maintened since 2007: Markus Baertschi (markus@markus.org)
 
 =head1 COPYRIGHT
 
@@ -1369,6 +1319,4 @@ modify this module as you wish, but if you redistribute a
 modified version, please attach a note listing the modifications
 you have made.
 
-Copyright 2007-, Markus Baertschi
-
 =cut
